@@ -1,6 +1,11 @@
-# Copyright 2006-7 by Roger Bivand
+# Copyright 2006-14 by Roger Bivand
 #
 
+setAs("listw", "CsparseMatrix", function(from) {as(as_dgRMatrix_listw(from), "CsparseMatrix")})
+setAs("listw", "RsparseMatrix", function(from) {as_dgRMatrix_listw(from)})
+setAs("listw", "symmetricMatrix", function(from) {as_dsTMatrix_listw(from)})
+
+
 as_dgRMatrix_listw <- function(listw) {
 	if(!inherits(listw, "listw")) stop("not a listw object")
 	n <- length(listw$neighbours)
@@ -11,6 +16,8 @@ as_dgRMatrix_listw <- function(listw) {
 		as.integer(cardw), as.integer(scard), PACKAGE="spdep")
 	res <- new("dgRMatrix", j=z[[1]], p=p0, Dim=as.integer(c(n, n)),
 		x=z[[2]])
+        colnames(res) <- attr(listw$neighbours, "region.id")
+        rownames(res) <- colnames(res)
 	res
 }
 
@@ -27,6 +34,8 @@ as_dsTMatrix_listw <- function(listw) {
 
 	res <- new("dsTMatrix", i=z[[1]], j=z[[2]], Dim=as.integer(c(n, n)),
 		x=z[[3]])
+        colnames(res) <- attr(listw$neighbours, "region.id")
+        rownames(res) <- colnames(res)
 	res
 }
 
